@@ -2,6 +2,7 @@ use strict; use warnings;
 package Lingy::Lang::Nil;
 
 use base 'Lingy::Lang::ScalarClass';
+use Lingy::Common;
 
 {
     package Lingy::Common;
@@ -11,4 +12,8 @@ use base 'Lingy::Lang::ScalarClass';
     sub nil { $nil }
 }
 
+sub _to_seq {
+    nil
+}
+
 1;
