@@ -1,8 +1,6 @@
 use strict; use warnings;
 package Lingy::RT;
 
-use base 'Lingy::Lang::Class';
-
 use Lingy::Eval;
 use Lingy::Lang::Class;
 use Lingy::Lang::List;
@@ -10,49 +8,72 @@ use Lingy::Lang::String;
 use Lingy::Namespace();
 use Lingy::ReadLine;
 
-use constant host => 'perl';
+use constant LANG => 'Lingy';
+use constant HOST => 'perl';
 
-our $env_class = 'Lingy::Env';
-our $printer_class = 'Lingy::Printer';
-our $reader_class = 'Lingy::Reader';
-
-our $util_class = 'Lingy::Util';
+use constant env_class => 'Lingy::Env';
+use constant printer_class => 'Lingy::Printer';
+use constant reader_class => 'Lingy::Reader';
+use constant util_class => 'Lingy::Util';
 
 our $ns = '';               # Current namespace name
 our %ns = ();               # Map of all namespaces
 our %refer = ();            # Map of all namespace refers
+bless \%ns, 'lingy-internal';
+bless \%refer, 'lingy-internal';
 
-sub class { Lingy::Lang::Class->_new(@_) }
-
-our %class = (              # Preload lingy.lang.Xyz classes:
-    'lingy.lang.Atom'       => class('Lingy::Lang::Atom'),
-    'lingy.lang.Boolean'    => class('Lingy::Lang::Boolean'),
-    'lingy.lang.Class'      => class('Lingy::Lang::Class'),
-    'lingy.lang.Character'  => class('Lingy::Lang::Character'),
-    'lingy.lang.Function'   => class('Lingy::Lang::Function'),
-    'lingy.lang.HashMap'    => class('Lingy::Lang::HashMap'),
-    'lingy.lang.Keyword'    => class('Lingy::Lang::Keyword'),
-    'lingy.lang.List'       => class('Lingy::Lang::List'),
-    'lingy.lang.Macro'      => class('Lingy::Lang::Macro'),
-    'lingy.lang.Nil'        => class('Lingy::Lang::Nil'),
-    'lingy.lang.Number'     => class('Lingy::Lang::Number'),
-    'lingy.lang.Macro'      => class('Lingy::Lang::Macro'),
-    'lingy.lang.Numbers'    => class('Lingy::Lang::Numbers'),
-    'lingy.lang.RT'         => class('Lingy::Lang::RT'),
-    'lingy.lang.String'     => class('Lingy::Lang::String'),
-    'lingy.lang.Symbol'     => class('Lingy::Lang::Symbol'),
-    'lingy.lang.Thread'     => class('Lingy::Lang::Thread'),
-    'lingy.lang.Var'        => class('Lingy::Lang::Var'),
-    'lingy.lang.Vector'     => class('Lingy::Lang::Vector'),
+our @class = (
+    'Lingy::Lang::Atom',
+    'Lingy::Lang::Boolean',
+    'Lingy::Lang::Class',
+    'Lingy::Lang::Character',
+    'Lingy::Lang::Function',
+    'Lingy::Lang::HashMap',
+    'Lingy::Lang::Keyword',
+    'Lingy::Lang::List',
+    'Lingy::Lang::Macro',
+    'Lingy::Lang::Nil',
+    'Lingy::Lang::Number',
+    'Lingy::Lang::Macro',
+    'Lingy::Lang::Numbers',
+    'Lingy::Lang::Regex',
+    'Lingy::Lang::RT',
+    'Lingy::Lang::String',
+    'Lingy::Lang::Symbol',
+    'Lingy::Lang::Term',
+    'Lingy::Lang::Thread',
+    'Lingy::Lang::Var',
+    'Lingy::Lang::Vector',
 );
 
+# Preload classes:
+our %class = map {
+    my $class = Lingy::Lang::Class->_new($_);
+    ($class->_name, $class);
+} @class;
+
 our ($env, $reader, $printer);
-our ($util);
-our ($core, $user);
+our ($rt, $core, $util, $user);
 
 my $pr_str;
 
+sub rt { $rt }
+sub ns { \%ns }
+sub NS { $ns{$ns} }
+sub refer { \%refer }
+sub env { $env }
+sub core { $core }
+sub util { $util }
+sub user { $user }
+
+sub new {
+    my ($class) = @_;
+    $rt = bless {}, $class;
+}
+
 sub init {
+    my ($self) = @_;
+
     for my $class (keys %class) {
         my $package = $class{$class};
         eval "require $package";
@@ -62,30 +83,28 @@ sub init {
         }
     }
 
-    $env     = require_new($env_class);
-    $reader  = require_new($reader_class);
-    $printer = require_new($printer_class);
-    $util    = require_new($util_class);
+    $env     = $self->require_new($self->env_class);
+    $reader  = $self->require_new($self->reader_class);
+    $printer = $self->require_new($self->printer_class);
+    $util    = $self->require_new($self->util_class);
 
     $pr_str = $printer->can('pr_str') or die;
 
-    $core = core_namespace();
+    $core = $self->core_namespace();
+    $user = $self->user_namespace();
 
-    $user = Lingy::Namespace->new(
-        name => 'user',
-        refer => [
-            $core->NAME,
-            $util->NAME,
-        ],
-    )->current;
+    $user->current;
 
-    return shift;
+    $Lingy::RT::ready = 1;
+
+    return $self;
 }
 
 sub core_namespace {
+    my ($self) = @_;
+
     my $ns = Lingy::Namespace->new(
         name => 'lingy.core',
-        delay => 1,
     )->current;
 
     my $argv = @ARGV
@@ -98,21 +117,38 @@ sub core_namespace {
     $env->set(concat => \&Lingy::Lang::RT::concat);
     $env->set(eval => sub { Lingy::Eval::eval($_[0], $env) });
 
+    # Clojure dynamic vars:
     $env->set('*file*', Lingy::Lang::String->new(
         $ARGV[0] || "NO_SOURCE_PATH"
     ));
-    $env->set('*ARGV*', $argv);
     $env->set('*command-line-args*', $argv);
-    $env->set('*host*', Lingy::Lang::String->new(host));
+
+    # Lingy dynamic vars:
+    $env->set('*ARGV*', $argv);
+    $env->set('*LANG*', Lingy::Lang::String->new($self->LANG));
+    $env->set('*HOST*', Lingy::Lang::String->new($self->HOST));
 
     my $core_ly = $INC{'Lingy/RT.pm'};
     $core_ly =~ s/RT\.pm$/core.ly/;
-    Lingy::RT->rep(slurp($core_ly));
+    $self->rep($self->slurp($core_ly));
 
     return $ns;
 }
 
+sub user_namespace {
+    my ($self) = @_;
+
+    Lingy::Namespace->new(
+        name => 'user',
+        refer => [
+            $self->core,
+            $self->util,
+        ],
+    );
+}
+
 sub require_new {
+    my $self = shift;
     my $class = shift;
     eval "require $class; 1" or
         die "Can't require '$class':\n$@";
@@ -120,7 +156,7 @@ sub require_new {
 }
 
 sub slurp {
-    my ($file) = @_;
+    my ($self, $file) = @_;
     open my $slurp, '<', "$file" or
         die "Couldn't read file '$file'";
     local $/;
@@ -128,10 +164,10 @@ sub slurp {
 }
 
 sub rep {
-    my ($self, $str, $prn) = @_;
+    my ($self, $str, $repl) = @_;
     my @ret;
-    for ($reader->read_str($str)) {
-        if ($prn) {
+    for ($reader->read_str($str, $repl)) {
+        if ($repl) {
             my $ret = eval { $pr_str->(Lingy::Eval::eval($_, $env)) };
             $ret = $@ if $@;
             chomp $ret;
@@ -145,11 +181,11 @@ sub rep {
 
 sub repl {
     my ($self) = @_;
-    $self->rep(q< (println (str "Welcome to Lingy [" *host* "]\n"))>)
+    $self->rep(q< (println (str "Welcome to " *LANG* " [" *HOST* "]\n"))>)
         unless $ENV{LINGY_TEST};
     while (defined (my $line = Lingy::ReadLine::readline)) {
         next unless length $line;
-        eval { $self->rep("$line", 'prn') };
+        eval { $self->rep("$line", 'repl') };
         print $@ if $@;
     }
     print "\n";
